function [s] = chkcir(range,spos,kmin,kmax)

% function [s] = chkcir(range,spos,kmin,kmax)
% CHKCIR checks whether kmin or kmin/kmax lies in stable region
% CHKCIR returns s = 1 if nyquist criteria is satisfied, s = 0 otherwise

% If lower bound is given, the function checks one point that corresponds
% to the minimum gain.
% If both the minimum and the maximum gain are given, the function checks
% if both points lie within any stable region.

% Sept 21, 25 Oct 21,23,24, Nov 1
%% 30 Apr 1999 - adjusted logic to work correctly if kmin = NaN ...
%%               (was broken by matlab syntax changes) - JH Taylor
% 2004 June 30 July 1

if nargin == 0
    display('USAGE: [s] = chkcir(range,spos,kmin,kmax)')
    return
elseif nargin < 3
    error('you have to set four input arguments!')
end
if nargin == 4, 
   if kmin < 0 & kmax < 0,                  % e.g kmin = -3   & kmax = -1
      Gmin = -1/kmin ; Gmax = -1/kmax;      % e.g Gmin = 1/3  & Gmax = 1 
   elseif kmin < 0 & kmax == 0,             % e.g kmin = -3   & kmax = 0
      Gmin = -1/kmin ; Gmax = +inf;         % e.g Gmin = 1/3  & Gmax = inf
   elseif kmin > 0 & kmax > 0,              % e.g kmin = 1    & kmax = 3
      Gmin = -1/kmin ; Gmax = -1/kmax;      % e.g Gmin = -1   & Gmax = 1/3
   elseif kmin == 0 & kmax > 0,             % e.g kmin = 0    & kmax = 3
       Gmin = -inf ; Gmax = -1/kmax;        % e.g Gmin = -inf & Gmax = -1/3
   elseif isnan(kmin),                      % isnan like 0/0 | inf/inf | inf/0
      %%%          disp('testing NaN code');
      if kmax == 0, 
         Gmin = inf ; Gmax = Gmin ; kmin = kmax;
      else  
         Gmin = -1/kmax ; Gmax = Gmin; kmin = kmax;
      end
   else  
      Gmin = -1/kmax ; Gmax = -1/kmin; 
   end
else
   if kmin == 0,
      Gmin = -inf; Gmax = Gmin ; kmax = kmin;
   else    
      Gmin = -1/kmin ; Gmax=Gmin ; kmax = kmin;
   end
end   
for x = 1:size(range,1),
   if spos(x), 
      % must check >= and <= if kmin=0 or kmax=0,   
      if kmin ~= 0 & kmax ~= 0,
         if Gmin > range(x,1) & Gmax < range(x,2),
            s = 1; return;
         end
      else  
         if Gmin >= range(x,1) & Gmax <= range(x,2),
            s = 1; return;
         end
      end
      % special case when kmin <0, kmax >0
      if kmin < 0 & kmax > 0,
         if (-1/kmax) < range(1,2) & (-1/kmin) > range(size(range,1),1)
            s = 1; return;
         end
      end
   end       
end
% return state =0 if gain does not lie in stable region
s=0;
      
