function [Gmin,Wmin] = fdmin(num,den,kmin)

% function [Gmin,Wmin] = fdmin(num,den,kmin)
% FDMIN finds the left most point on the nyquist curve 
% express the num/den in real & imag part, 
% find the derivative of real part as a function of freq w,
% the positive root is the w that gives minimum real part  
% FDMIN returns the most negative real number on nyquist curve

% FDMIN finds the most negative number of a transfer function by
% taking its derivative . If the most negative number happens to
% be positive, the function will return zero as the most negative
% number.In this way, the circle can cross the imaginary axis only
% when the gain bounds are of different signs.

% 96 Sept 20, 22, 23, 24, 25 Nov 28 
% 97 May 15,27
% 2004 July 1,2

nar = 3;    % number of input arguments
if nargin == 0
    display('USAGE: [Gmin,Wmin] = fdmin(num,den,kmin)')
    return
elseif nargin < 3
    msgbox(['i told you before to include ',num2str(nar),' input arguments!!'])
end
[num1,den1] = clean(num,den);
[num,den] = s2jw(num,den);
u = real(conv(num,conj(den))); 
% small imaginary number must be ignored
v = real(conv(den,conj(den)));
uprime = polyder(u);    % get the derivative of u
vprime = polyder(v);    % get the derivative of v
vuprime = conv(v,uprime);
uvprime = conv(u,vprime);
[uvprime,vuprime] = addz(uvprime,vuprime);

% e.g if G = num/den then dG = (dnum*den - dden*num)/den^2
% where dnum = derivative of numerator   & dden =derivative of denominator
equation = vuprime - uvprime;             
equation = clean(equation);
Wmin = roots(equation);

% choose only positive real frequency, no imaginary part
ind = find(Wmin >= 0 & imag(Wmin) == 0);

% consider that some Gmin contain imaginary value
Gmin = freqresp(num1,den1,j*Wmin(ind));
if length(num) == length(den),
   Gmin(length(Gmin)+1) = num(1)/den(1);
   Wmin(length(Wmin)+1) = inf; 
else
   Gmin(length(Gmin)+1) = 0;
   Wmin(length(Wmin)+1) = inf;
end
Gmin = min(real(Gmin));


   
