function plotc(kmin, kmax, num, den, limit)

% function plotc(kmin, kmax, num, den) plots the circle defined by kmin,kmax
% by changing from nyq4p2(old nyquist in matlab version 4.2) to nyquist , 
% the color of the nyquist plot changes and the simulation is much faster

% 96 Sept 21,25, Oct 24,28,30, Nov21,27
% 97 May 27 Oct 15
% 2004 July 1,8,10

if nargin == 0
    display('USAGE: plotc(kmin,kmax,num,den,limit')
    return
elseif nargin < 5
    error('please insert 5 input arguments!!')
end
if kmax == 0,
   Gmin = -inf; Gmax = -1/kmin;
elseif kmin < 0 & kmax > 0,
   Gmin = -1/kmax; Gmax = -1/kmin;
elseif kmin == 0,
   Gmin = -inf; Gmax = -1/kmax;
else  
   Gmin = -1/kmin; Gmax = -1/kmax; 
end  

if (Gmin ~= -inf) & (Gmax ~= inf),
   xmid = (Gmin + Gmax)/2;          % center of the circle
   r = (Gmax - Gmin)/2;               % radius of the circle
   x = xmid + r*cos(0:0.1:2*pi);
   y = r*sin(0:0.1:2*pi);
   plot(x,y,'r');
   % plot right-hand-mapping for circle 
   if (Gmin < 0 & Gmax > 0) | (Gmin == 0 & Gmax > 0) , 
      x1 = xmid + r*cos(0:0.1:pi);
      y1 = r*sin(0:0.1:pi);
   else
      x1 = xmid + r*cos(2*pi:-0.1:pi); 
      y1 = r*sin(2*pi:-0.1:pi);
   end
   hold on; 
   rplot(x1,y1);
   hold off;
   limit = axis; 
   xmin = limit(1); xmax = limit(2);
   ymin = limit(3); ymax = limit(4);
   hold on;
   nyq4p2(num,den);
   hold off;
else
   % circle degenerates to a line, either kmin or kmax equals to zero
   nyq4p2(num,den); 
   xmin = limit(1); xmax = limit(2);
   ymin = limit(3); ymax = limit(4);
   if Gmin == -inf, 
      if Gmax > xmax,
         xmin = limit(1); xmax = Gmax;
      elseif Gmax < xmin, 
         xmin = Gmax; xmax = limit(2);
      end
      hold on;
      plot([Gmax, Gmax],[ymin, ymax],'r');
      hold off;  
   else 
      if Gmin > xmax,
         xmin = limit(1); xmax = Gmin; 
      elseif Gmin < xmin, 
         xmin = Gmin, xmax = limit(2);
      end
      hold on; 
      plot([Gmin, Gmin],[ymin, ymax],'r'); 
      hold off;        
   end
end    
if abs(xmin) >  abs(xmax),
   x = 1.1*abs(xmin); 
else
   x = 1.1*abs(xmax);
end
axis([-x, x, ymin, ymax]);


