function [Gre, Gim, w] = addp(Gre, Gim, w, num, den, Groot, freq)

% [Gre, Gim, w] = addp(Gre, Gim, w, num, den, Groot, freq)
% adds the first point at w=0 if it does not exist, last point at w=inf
% and extra point to ensure the # of crossing is equal to RE-axis root
% Gre is the real part of the real axis root
% Gim is the imaginary part of the real axis 
 
% 96 July 18
% 97 May 21,22,23 June 3
% 2004 June 24 -- KMMA
% 2004 Nov 15 -- JHT
% 2008 Apr 25 -- JHT - disabled debug test on nargin, forced w1 = w1(:), line 55

% error checking for debugging
if nargin == 0
    display('USAGE: [Gre,Gim,w]=addp(Gre,Gim,w,num,den,Groot,freq)')
    return
%jht elseif nargin ~= 5 or nargin ~= 7
%jht     error('wrong number of input arguments')
end
% add first point if it does not exist
% consider only transfer function with no poles at origin
%jht if ~isempty(den(length(den)))               % e.g. den = s^2 + s
if den(length(den)) ~= 0,               % e.g. den = s^2 + s
   pt1 = freqresp(num,den,j*0);
   if pt1 ~= Gre(1), 
      Gre = [pt1; Gre];
      Gim = [0; Gim];
      w = [0; w]; 
   end
end

% add last point at w=inf
if length(num) < length(den), 
   Gre(length(Gre)+1,:) = 0;
   Gim(length(Gim)+1,:) = 0;
else
   Gre(length(Gre)+1,:) = num(1,1)/den(1,1);
   Gim(length(Gim)+1,:) = 0;
end
w(length(w)+1,:) = inf;

if nargin == 7,
   % add point(s) in between RE-axis root(s) to ensure pt2nd 
   % will detect the same number as the Groot -- fixed, jht
   if length(Groot) > 1,
      for k = 1:length(Groot)-1,
         w1(k) = ( freq(k) + freq(k+1) )/2;
         s = freqresp(num,den,j*w1(k));
         Gre1(k,:) = real(s);         % real part of the root location
         Gim1(k,:) = imag(s);         % imaginary part of the root location
      end
   end
   w = [w1(:);w];
   Gre = [Gre1;Gre];
   Gim = [Gim1;Gim];
   [sortw,sort_ind] = sort(w);  % sortw = sorting (w) in ascending order & sort_ind = indice of (w) sorted
   Gre = Gre(sort_ind);
   Gim = Gim(sort_ind); 
end
