function [Groot,freq,num,den] = findrt(a,b,c,d)

% FINDRT  find all root locations on real axis of the transfer function
%         it returns all RE-axis roots except last root at w=inf, and 
%         returns to transfer function num, den if a,b,c,d matrix are used.
%         The tolerance level for the real axis roots is the imaginary part
%         of these roots smaller than 1e-10.When changing the state space
%         matrix to the transfer function,any element in the vector
%         numerator and denominator smaller than 1e-10 is ignored.

% 96 May 22,24 June 6,16,26 July 16 Aug 12,13,14,17,19 Sept 24 
% 97 May 6,15,16,26 June 3
% 2004 June 17 20

if nargin == 0
    disp('USAGE : [Groot,freq,num,den] = findrt(a,b,c,d)')
    return
end
if nargin == 2, 
   num = a; den = b;
   [mnum,nnum] = size(num);
   [mden,nden] = size(den);
    % Check for null systems
   if  (nden == 0 & nnum == 0), a=[]; b=[]; c=[]; d=[];
       return,
   end
   if min(mden,nden) > 1,
        % Error out if DEN is an array
        error('Denominator must be a row vector.');
   elseif mden > 1,
        % Transpose DEN when a column vector
        den = den.';
   end
else
   [num,den] = ss2tf(a,b,c,d);
   [num,den] = clean(num,den); 
end
% save num and den   
num1 = num; den1 = den; 
[num,den] = s2jw(num,den);
 %                     (1 + s)
 %  e.g. num/den = --------------  
 %                  (s^2 + s + 1)

requation = conv(num,conj(den));            %                     (1 + jw) * conj(den)           (1+jw)*((1-w^2)-jw)           
iequation = imag(requation);                % e.g. num/den =  ----------------------------- = --------------------------
                                            %                 ((-w^2 + 1) + jw) * conj(den)   ((1-w^2)+jw))*((1-w^2)-jw)   
% imag equation = zero needs special treatment
if ~all(iequation == 0),
   Rim = roots(iequation);
   % w must be a positive number with very small imaginary part 
   if den(length(den)) == 0,         
       %             1           1
       % e.g.      ------  =   ------ 
       %          (s^2+s)      s(s+1)
       % w = zero is ignored for pole at origin. 
       % it gives error divide by zero 
      ind = find(Rim > 0 & abs(imag(Rim)) < 1e-10);   % find only the +ve frequency indices
   else
      ind = find(Rim >= 0 & abs(imag(Rim)) < 1e-10);
   end
end
% obtain all root locations on real axis of positive w
if ~all(iequation==0),
   w=Rim(ind);
   if nargin == 2,   
      Grootloc = polyval(num, Rim(ind)) ./ polyval(den, Rim(ind));
   else
      % more accurate to use a,b,c,d if possible
      Grootloc = freqresp(a,b,c,d,1,j*Rim(ind));        % 1 means Tsampling (continuous system)
   end
elseif num == 1 & den(length(den)) == 0,
   Grootloc = []; 
   w = [];
else   
   Grootloc = freqresp(num1, den1, j*0); 
   w = 0;
end
% special case when Grootloc have large imag value and zero real value 
if ~isempty(Grootloc),
   if all(real(Grootloc) == 0) & ~all(imag(Grootloc) == 0), 
      ind = find(imag(Grootloc) ~= 0); 
      w(ind) = [];
   end
end
% ignore small imaginary value which should be zero
Grootloc = real(Grootloc);
if nargin == 4, 
   num = num1; den = den1;
end
% erase roots and frequencies that are the same
Groot = erase(Grootloc);
freq = erase(w);
