function [position] = pt2nd(Gre, Gim)

% function [position] = pt2nd(Gre, Gim)
% locates all 2nd point positions where frequency increases from 1st point 
% to RE-axis root to 2nd point, except at w=inf where first point is used 
% pt2nd returns all 2nd point positions, except the last RE-axis root uses
% 1st point instead

% 96 May 21,22,23,24 June 4, Sept 21, 
% 97 Jan 27 May 10
% 2004 august 24

if nargin == 0
    disp('USAGE: [position] = pt2nd(Gre,Gim)')
    return
elseif nargin < 2
    error('not enough input arguments')
end
% initialize position to null in case it is not assigned a value
position=[];
Lpoint = length(Gre);
% handle special case when first point is exactly on the axis
if Gim(1)==0,
   position(1,:) = 2;
   vind = 2; jp = 1;   % set counters (vind) from the second point and (jp) from the first point
else
   vind = 1; jp = 1; 
end
% check sign change to locate upper and lower bound
while jp < Lpoint-1,
   if (Gim(jp)>0 & Gim(jp+1)<0) | (Gim(jp)<0 & Gim(jp+1)>0),
      position(vind,:) = jp + 1;
      vind = vind + 1;
   end
   jp = jp + 1;
end
% last w root uses 1st/root point instead of 2nd/root point
position(length(position)+1,:)= length(Gre)-1;


