function [range] = region(Groot)

% function [range] = region(Groot) assigns regions divided by the RE-axis roots
% REGION returns two columns of region bounds : upper and lower bound.
% REGION are assigned in the order from -inf to +inf, 
% for example, if Groot = real axis roots = [-1 0 1 ]
% so the regions would be as follows:
% -inf -1
%  -1   0
%   0   1
%   1   inf

% 96 May 27 June 6 Aug 12 , 97 May 10,23 June 3
% 2004 June 19

if nargin == 0
    display('USAGE: [range]= region(Groot)')
    return
end
if ~isempty(Groot),
    Groot = sort(Groot);
    range(1,1) = -inf;
    range(1,2) = min(min(Groot));  % min(Groot)
    k = 2;                        % initialize the second row
    for x = 1:length(Groot)-1
        range(k,1) = Groot(x);
        range(k,2) = Groot(x+1);
        k = k + 1;
    end
    range(k,1) = max(max(Groot)); % max(Groot)
    range(k,2) = inf; 
    % remove region that reduces to a single point
    len = size(range,1);
    x = 1;                % reset x to reuse it again
    while x < len + 1
        if range(x,1) == range(x,2), 
            range(x,:) = [];
            len = size(range,1);
            x = x - 1;   %check the same row again
        end
        x = x + 1;
    end 
else
    range=[-inf 0; 0 inf];
end
