function [vectx, vecty] = rhand(x,y)

% function [vectx, vecty] = rhand(x,y) 
% accept two points in form x = [x1 x2], y = [y1 y2]
% return vectx = [xm, xn]' , vecty = [ym, yn]'

% Supplied by the frequency data from the nyquist ,find the distance 
% between all consecutive points ."w" moves in the direction of 
% 1_st point then 2_nd point. 

% Because the nyquist path is chosen to be the region not enclosed by 
% the RHP mapping.This problem is solved by taking the frequency data 
% from the nyquist ,finding the distance between all the consecutive
% points and drawing a perpendicular line at the midpoint between each pair
% of points according to the following rule.

% The purpose of this function is to point towards the right hand 
% mapping for each point on the plot. [xm ym] is the mid point between
% [x1,y1] and [x2,y2] . [xn yn] is the point perpendicular to [xm,ym]

% perpendicular vectors have the relations A.B = 0,
% so [x2-x1 , y2-y1].[xn-xm , ym-yn] = 0

% 97 May 8,9,10,23,29
% 2004 June 6,30

% Error checking
if nargin == 0
    display('USAGE: [vects, vecty]=rhand(x,y)')
    return
elseif nargin < 1 | nargin > 2
    error('Incorrect number of input arguments!')
end
xm = ( x(1) + x(2) )/2;
ym= ( y(1) + y(2) )/2;
deltax = x(2) - x(1);
deltay = y(2) - y(1);
xn = xm + deltay;
yn = ym - deltax;
vectx = [xm, xn]';
vecty = [ym, yn]';


