function [stabpos,nrhp] = stab1(clds)

% function [stabpos,nrhp] = stab1(clds)
% checks the number of RHP zeros for each closed-loop
% characteristic equation (denominator poly) corresponding
% to each 'region' on the real axis defined by testpt; clds
% is the set of such denominator polynomials, stabpos is the
% index of each stable closed-loop denominator poly, and
% nrhp indicates the corresponding unstable pole number.

% The definition of asymptotic stability is used,
% so poles on the imaginary axis are counted as
% unstable poles.

% 96 June 14 July 17
% 2004 June 29,30

if nargin == 0
   display('USAGE: [stabpos,nrhp] = stab1(clds)')
   return
end
for k = 1: size(clds,1)
   sroot = roots(clds(k,:));
   % test the real part of each root to check stability
   sroot = real(sroot);
   % initialize the number of zeros of RHP of 1 + k*G(s)
   nrhp(k,:) = 0;
   for x = 1:length(sroot)
      % use asymptotic stability, poles on imag axis are unstable 
      if sroot(x) >= 0, 
         nrhp(k,:) = nrhp(k,:) + 1;  % count the RHP zeros 
      end
   end
end
% obtain stable k position
for k = 1:length(nrhp)
   if nrhp(k) == 0,       % stable system 
      stabpos(k,:) = k;
   else                    % unstable system
      stabpos(k,:) = 0;
   end
end



